==> nextcloud-app-notes-3.4.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/notes/l10n/de_DE.js <==
OC.L10N.register(
    "notes",
    {
    "Notes" : "Notizen",
    "The last viewed note cannot be accessed. " : "Auf die zuletzt betrachtete Notiz kann nicht zugegriffen werden.",
    "The notes folder is not accessible: %s" : "Auf den Notizordner kann nicht zugegriffen werden: %s",
    "Error" : "Fehler",
    "New note" : "Neue Notiz",
    "Distraction-free notes and writing" : "Ablenkungsfreie Notizen und Schreiben",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](docs/api/README.md) allows for an easy integration into third-party apps (currently, there are notes apps for [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) and the [console](https://git.danielmoch.com/nncli/about) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Die Notes-App ist eine leicht zu bedienende App zum Erstellen von Notizen in der [Nextcloud](https://www.nextcloud.com/). Zur besseren Übersicht bietet diese die Möglichkeit zur Einordnung der Notizen in Kategorien. Für die Formatierung wird [Markdown](https://en.wikipedia.org/wiki/Markdown)-Syntax unterstützt. Notizen werden als Dateien in der Nextcloud abgelegt. So kann diese mit jedem Nextcloud-Client editiert werden. Des Weiteren erlaubt eine separate [REST API](docs/api/README.md) die einfache Integration in Drittanbieter-Apps (aktuell gibt es Notes-Apps für [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) und die [Konsole](https://git.danielmoch.com/nncli/file/README.rst.html) welche bequemen Zugang zu den Notizen in der Nextcloud erlauben). Weitere Funktionen ermöglichen es unter anderem Notizen als Favoriten zu markieren.",
    "Settings" : "Einstellungen",
    "Deleted {title}" : "{title} gelöscht",
    "Deleted {number} notes" : "{number} Notizen gelöscht",
    "Undo Delete" : "Wiederherstellen",
    "Please chose a valid path in {label} (bottom left corner)." : "Bitte wählen Sie einen geeigneten Verzeichnispfad in den {label} (unten links).",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Es existieren nicht-gespeicherte Notizen. Beim Verlassen der Seite gehen alle Änderungen verloren!",
    "Folder to store your notes" : "Ordner zum Speichern Ihrer Notizen",
    "path to notes" : "Pfad zu Notizen",
    "File extension for new notes" : "Dateiendung für neue Notizen",
    "All notes" : "Alle Notizen",
    "Categories" : "Kategorien",
    "No search result for “{search}” in {category}" : "Kein Suchergebnis für „{search}“ in {category}",
    "No search result for “{search}”" : "Kein Suchergebnis für „{search}“",
    "Loading …" : "Lade …",
    "Search result for “{search}” in {category}" : "Suchergebnis für „{search}“ in {category}",
    "Search result for “{search}”" : "Suchergebnis für „{search}“",
    "Today" : "Heute",
    "Yesterday" : "Gestern",
    "This week" : "Diese Woche",
    "Last week" : "Letzte Woche",
    "This month" : "Dieser Monat",
    "Last month" : "Letzter Monat",
    "Rename" : "Umbenennen",
    "Note's title" : "Titel der Notiz",
    "Delete note" : "Notiz löschen",
    "Remove from favorites" : "Von Favoriten entfernen",
    "Add to favorites" : "Zu Favoriten hinzufügen",
    "Error during preparing note for deletion." : "Fehler beim Vorbereiten der Notiz für die Löschung.",
    "Empty note" : "Leere Notiz",
    "Write …" : "Schreibe …",
    "Details" : "Details",
    "Preview" : "Vorschau",
    "Edit" : "Bearbeiten",
    "Exit full screen" : "Vollbild verlassen",
    "Full screen" : "Vollbild",
    "Save failed. Click to retry." : "Speichern fehlgeschlagen. Klicken um es erneut zu versuchen.",
    "Set category" : "Kategorie ändern",
    "Category" : "Kategorie",
    "Uncategorized" : "Ohne Kategorie",
    "Click here to save manually" : "Hier Klicken um manuell zu speichern",
    "Saving failed!" : "Speichern fehlgeschlagen!",
    "Last modified: {date}" : "Zuletzt geändert: {date}",
    "Note has unsaved changes" : "Notiz enthält nicht gespeicherte Änderungen",
    "Subcategory" : "Unterkategorie",
    "_%n word_::_%n words_" : ["%n Wort","%n Wörter"],
    "Write down your thoughts without any distractions." : "Schreiben Sie Ihre Gedanken ohne jegliche Störungen auf.",
    "Use Markdown markups to style your text." : "Verwenden Sie Markdown um Ihren Text zu gestalten.",
    "Organize your notes in categories." : "Sortieren Sie Ihre Notizen in Kategorien.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Installieren Sie die mobile App um Ihre Notizen von überall zu nutzen.",
    "Android app" : "Android-App",
    "iOS app" : "iOS-App",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Erstellen Sie eine Notiz per Klick auf „{newnote}“ in der App-Navigation.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Sie können Unterkategorien erstellen indem Sie „/“ als Trennung zwischen Ober- und Unterkategorie verwenden, z.B. „{parent}/{sub}“.",
    "See JavaScript console and server log for details." : "Siehe JavaScript-Konsole und Server-Protokoll für Details.",
    "Saving the note has failed due to insufficient storage." : "Die Notiz konnte nicht gespeichert werden weil kein Speicherplatz verfügbar ist.",
    "Updating settings has failed." : "Aktualisierung der Einstellungen fehlgeschlagen.",
    "Fetching notes has failed." : "Laden der Notizen fehlgeschlagen.",
    "Fetching note {id} has failed." : "Abruf der Notiz {id} fehlgeschlagen.",
    "Renaming note {id} has failed." : "Umbenennen der Notiz {id} fehlgeschlagen.",
    "Creating new note has failed." : "Erstellen der neuen Notiz fehlgeschlagen.",
    "Updating note {id} has failed." : "Aktualisierung der Notiz {id} fehlgeschlagen.",
    "Undo delete has failed for note {title}." : "Fehler beim Wiederherstellen der Notiz {title}.",
    "Deleting note {id} has failed." : "Löschen der Notiz {id} fehlgeschlagen.",
    "Toggling favorite for note {id} has failed." : "Setzen der Notiz {id} als Favorit fehlgeschlagen.",
    "Updating the note's category has failed. Is the target directory writable?" : "Aktualisierung der Notizen-Kategorie ist gescheitert. Bestehen Schreibrechte für das Zielverzeichnis?",
    "Updating the category for note {id} has failed." : "Ändern der Kategorie für Notiz {id} fehlgeschlagen.",
    "Development Mode" : "Entwickler-Modus",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Es scheint, dass die Notizen-App von einer Entwickler-Quelle installiert wurde. Bitte stattdessen von dem offiziellen <a href=\"%1$s\">Nextcloud-App-Store</a> installieren. Wenn Sie die Notizen-App selbst bauen möchten, folgen Sie bitte den <a href=\"%2$s\">Entwickler-Anleitungen</a>."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-notes-3.6.4-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/notes/l10n/de_DE.js <==
OC.L10N.register(
    "notes",
    {
    "Reading notes from filesystem has failed." : "Laden der Notizen vom Dateisystem ist fehlgeschlagen.",
    "Error" : "Fehler",
    "New note" : "Neue Notiz",
    "Notes" : "Notizen",
    "Distraction-free notes and writing" : "Ablenkungsfreie Notizen und Schreiben",
    "Please see Nextcloud server log for details." : "Für Details siehe Protokolldatei des Nextcloud-Servers.",
    "Deleted {title}" : "{title} gelöscht",
    "Deleted {number} notes" : "{number} Notizen gelöscht",
    "Undo Delete" : "Wiederherstellen",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Es existieren nicht-gespeicherte Notizen. Beim Verlassen der Seite gehen alle Änderungen verloren!",
    "Settings" : "Einstellungen",
    "Folder to store your notes" : "Ordner zum Speichern Ihrer Notizen",
    "path to notes" : "Pfad zu Notizen",
    "File extension for new notes" : "Dateiendung für neue Notizen",
    "All notes" : "Alle Notizen",
    "Categories" : "Kategorien",
    "No search result for “{search}” in {category}" : "Kein Suchergebnis für „{search}“ in {category}",
    "No search result for “{search}”" : "Kein Suchergebnis für „{search}“",
    "Loading …" : "Lade …",
    "Search result for “{search}” in {category}" : "Suchergebnis für „{search}“ in {category}",
    "Search result for “{search}”" : "Suchergebnis für „{search}“",
    "Today" : "Heute",
    "Yesterday" : "Gestern",
    "This week" : "Diese Woche",
    "Last week" : "Letzte Woche",
    "This month" : "Dieser Monat",
    "Last month" : "Letzter Monat",
    "Rename" : "Umbenennen",
    "Note's title" : "Titel der Notiz",
    "Delete note" : "Notiz löschen",
    "Remove from favorites" : "Von Favoriten entfernen",
    "Add to favorites" : "Zu Favoriten hinzufügen",
    "Error during preparing note for deletion." : "Fehler beim Vorbereiten der Notiz für die Löschung.",
    "Empty note" : "Leere Notiz",
    "Write …" : "Schreibe …",
    "Details" : "Details",
    "CTRL + /" : "STRG + /",
    "Edit" : "Bearbeiten",
    "Preview" : "Vorschau",
    "Exit full screen" : "Vollbild verlassen",
    "Full screen" : "Vollbild",
    "Save failed. Click to retry." : "Speichern fehlgeschlagen. Klicken um es erneut zu versuchen.",
    "Set category" : "Kategorie ändern",
    "Category" : "Kategorie",
    "Uncategorized" : "Ohne Kategorie",
    "Click here to save manually" : "Hier Klicken um manuell zu speichern",
    "Saving failed!" : "Speichern fehlgeschlagen!",
    "Last modified: {date}" : "Zuletzt geändert: {date}",
    "Note has unsaved changes" : "Notiz enthält nicht gespeicherte Änderungen",
    "Subcategory" : "Unterkategorie",
    "_%n word_::_%n words_" : ["%n Wort","%n Wörter"],
    "_%n character_::_%n characters_" : ["%n Zeichen","%n Zeichen"],
    "Write down your thoughts without any distractions." : "Schreiben Sie Ihre Gedanken ohne jegliche Störungen auf.",
    "Use Markdown markups to style your text." : "Verwenden Sie Markdown um Ihren Text zu gestalten.",
    "Organize your notes in categories." : "Sortieren Sie Ihre Notizen in Kategorien.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Installieren Sie die mobile App um Ihre Notizen von überall zu nutzen.",
    "Android app" : "Android-App",
    "iOS app" : "iOS-App",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Erstellen Sie eine Notiz per Klick auf „{newnote}“ in der App-Navigation.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Sie können Unterkategorien erstellen indem Sie „/“ als Trennung zwischen Ober- und Unterkategorie verwenden, z.B. „{parent}/{sub}“.",
    "Note not found." : "Notiz nicht gefunden.",
    "Note is locked." : "Notiz ist gesperrt.",
    "Insufficient storage." : "Speicherplatz nicht ausreichend.",
    "See JavaScript console and server log for details." : "Siehe JavaScript-Konsole und Server-Protokoll für Details.",
    "Updating settings has failed." : "Aktualisierung der Einstellungen fehlgeschlagen.",
    "Error from Nextcloud server: {msg}" : "Fehler vom Nextcloud-Server: {msg}",
    "Fetching notes has failed." : "Laden der Notizen fehlgeschlagen.",
    "Fetching note {id} has failed." : "Abruf der Notiz {id} fehlgeschlagen.",
    "Refreshing note {id} has failed." : "Aktualisieren der Notiz {id} fehlgeschlagen.",
    "Renaming note {id} has failed." : "Umbenennen der Notiz {id} fehlgeschlagen.",
    "Creating new note has failed." : "Erstellen der neuen Notiz fehlgeschlagen.",
    "Saving note {id} has failed." : "Speichern der Notiz {id} fehlgeschlagen.",
    "Updating title for note {id} has failed." : "Ändern des Titels für Notiz {id} fehlgeschlagen.",
    "Undo delete has failed for note {title}." : "Fehler beim Wiederherstellen der Notiz {title}.",
    "Deleting note {id} has failed." : "Löschen der Notiz {id} fehlgeschlagen.",
    "Toggling favorite for note {id} has failed." : "Setzen der Notiz {id} als Favorit fehlgeschlagen.",
    "Updating the note's category has failed. Is the target directory writable?" : "Aktualisierung der Notizen-Kategorie ist gescheitert. Bestehen Schreibrechte für das Zielverzeichnis?",
    "Updating the category for note {id} has failed." : "Ändern der Kategorie für Notiz {id} fehlgeschlagen.",
    "Development Mode" : "Entwickler-Modus",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Es scheint, dass die Notizen-App von einer Entwickler-Quelle installiert wurde. Bitte stattdessen von dem offiziellen <a href=\"%1$s\">Nextcloud-App-Store</a> installieren. Wenn Sie die Notizen-App selbst bauen möchten, folgen Sie bitte den <a href=\"%2$s\">Entwickler-Anleitungen</a>."
},
"nplurals=2; plural=(n != 1);");
